@@ -111,7 +111,10 @@ def likelihood_fit(**kwargs):
     df['pois']['prefit'] = analysis.model.as_dataframe('poi')
     df['nuisance_parameters']['prefit'] = analysis.model.as_dataframe('nuisance_parameter')
     analysis.load_snapshot("nllFit")
-    df['pois']['postfit'] = analysis.model.as_dataframe('poi')
+    if do_minos:
+        df['pois']['postfit'] = analysis.model.as_dataframe('poi', asym_error=True)
+    else:
+        df['pois']['postfit'] = analysis.model.as_dataframe('poi')
     df['nuisance_parameters']['postfit'] = analysis.model.as_dataframe('nuisance_parameter')
     if _kwargs['display']:
         import pandas as pd
@@ -121,7 +124,11 @@ def likelihood_fit(**kwargs):
         df[key]['combined']['value_prefit'] = df[key]['prefit']['value']
         df[key]['combined']['value_postfit'] = df[key]['postfit']['value']
         df[key]['combined']['error_prefit'] = df[key]['prefit']['error']
-        df[key]['combined']['error_postfit'] = df[key]['postfit']['error']
+        if (key == "pois") and do_minos:
+            df[key]['combined']['errorlo_postfit'] = df[key]['postfit']['errorlo']
+            df[key]['combined']['errorhi_postfit'] = df[key]['postfit']['errorhi']
+        else:
+            df[key]['combined']['error_postfit'] = df[key]['postfit']['error']
         output[key] = df[key]['combined'].to_dict("list")
         if _kwargs['display']:
             print("{}:".format(key.title()))
