@@ -37,6 +37,8 @@ import click
                    '\b\n Case -1: Jobs are run across N_CPU workers.')
 @click.option('-p', '--poi', 'poi_name', default=None,
               help='Name of the parameter of interest (POI). If None, the first POI is used.')
+@click.option('--mu_exp', type=float, default=0, show_default=True,
+              help='Expected signal strengh value to be used for Asimov generation')
 @click.option('-d', '--data', 'data_name', default='combData', show_default=True,
               help='Name of dataset')
 @click.option('--asimov_data_name', 'asimov_data_name', default=None,
