@@ -1,5 +1,5 @@
 from typing import Optional, Dict, List, Union
-from quickstats.utils.enums import GeneralEnum, DescriptiveEnum
+from quickstats import GeneralEnum, DescriptiveEnum
 import enum
 
 from quickstats.components import AnalysisObject
