@@ -17,8 +17,7 @@ from ROOT.RooPrintable import (kName, kClassName, kValue, kArgs, kExtras, kAddre
                                kTitle, kCollectionHeader, kSingleLine)
 
 import quickstats
-from quickstats import semistaticmethod
-from quickstats.components import AbstractObject
+from quickstats import semistaticmethod, AbstractObject
 from quickstats.maths.numerics import is_integer, pretty_value, get_bins_given_edges, array_issubset
 from quickstats.utils.root_utils import load_macro
 from quickstats.utils.common_utils import str_list_filter
@@ -157,7 +156,8 @@ class ExtendedModel(AbstractObject):
     def activate_binned_likelihood(self, ws):
         for component in ws.components():
             try:
-                flag = (component.IsA() == ROOT.RooRealSumPdf.Class())
+                # A pdf is binned if it has attribute "BinnedLikelihood" and it is a RooRealSumPdf (or derived class).
+                flag = component.IsA().InheritsFrom(ROOT.RooRealSumPdf.Class())
             except:
                 flag = (component.ClassName() == "RooRealSumPdf")
             if (flag):
