@@ -12,8 +12,7 @@ import numpy as np
 import ROOT
 
 import quickstats
-from quickstats import semistaticmethod, cls_method_timer
-from quickstats.components import AbstractObject
+from quickstats import semistaticmethod, AbstractObject
 from quickstats.utils.root_utils import load_macro, is_corrupt
 from quickstats.utils.common_utils import combine_dict, execute_multi_tasks
 
