@@ -5,8 +5,8 @@ import math
 import json
 from itertools import repeat
 
-from quickstats import semistaticmethod
-from quickstats.components import AbstractObject, ExtendedModel
+from quickstats import semistaticmethod, AbstractObject
+from quickstats.components import ExtendedModel
 from quickstats.maths.numerics import str_encode_value
 from quickstats.utils.common_utils import execute_multi_tasks
 from quickstats.utils.root_utils import load_macro
