@@ -1,18 +1,16 @@
+from typing import Optional, Union, List, Dict
 import os
 import re
 import time
 import difflib
 from functools import partial
-from typing import Optional, Union, List, Dict
 
 import numpy as np
 
 import quickstats
-from quickstats import semistaticmethod
-from quickstats.components import AbstractObject
+from quickstats import semistaticmethod, AbstractObject, GeneralEnum
 from quickstats.utils.io import Verbosity
 from quickstats.utils.xml_tools import TXMLTree
-from quickstats.utils.enums import GeneralEnum
 from quickstats.maths.numerics import to_bool
 from quickstats.utils.root_utils import load_macro,get_macro_TClass
 from quickstats.utils.common_utils import set_unlimited_stacksize
