@@ -20,7 +20,7 @@ class TH1(TObject):
         self.overflow_bin  = overflow_bin
         self.init(h)
         
-    def init(self, h):
+    def init(self, h:ROOT.TH1):
         self.bin_content  = self.GetBinContentArray(h, self.dtype, self.underflow_bin, self.overflow_bin)
         self.bin_error    = self.GetBinErrorArray(h, self.dtype, self.underflow_bin, self.overflow_bin)
         self.bin_center   = self.GetBinCenterArray(h, self.dtype, self.underflow_bin, self.overflow_bin)
@@ -63,7 +63,17 @@ class TH1(TObject):
             title = name
         return self._to_ROOT(name, self.bin_content, bin_low_edge=self.bin_low_edge,
                              bin_error=self.bin_error, title=title)
-        
+    
+    @staticmethod
+    def remove_negative_bins(h:ROOT.TH1):
+        py_h = TH1(h)
+        neg_bin_indices = np.where(py_h.bin_content < 0.)
+        neg_bin_values  = py_h.bin_content[neg_bin_indices]
+        neg_bins = neg_bin_indices[0] + 1
+        if len(neg_bins) > 0:
+            for i in neg_bins:
+                h.SetBinContent(int(i), 0.)
+        return neg_bin_indices, neg_bin_values
     @staticmethod
     def GetBinContentArray(h, dtype:str='double', underflow_bin:int=0, overflow_bin:int=0):
         c_vector = ROOT.TH1Utils.GetBinContentArray[dtype](h, underflow_bin, overflow_bin)
