@@ -5,6 +5,7 @@ import numpy as np
 import ROOT
 
 from quickstats.interface.cppyy.vectorize import list2vec, as_np_array
+from quickstats import _PRINT_
 
 def unfold_constraints(constraint_pdfs:ROOT.RooArgSet, observables:ROOT.RooArgSet,
                        nuisance_parameters:ROOT.RooArgSet, constraint_cls:Optional[List[str]]=None,
@@ -62,7 +63,7 @@ def pair_constraints(constraint_pdfs:ROOT.RooArgSet, nuisance_parameters:ROOT.Ro
     paired_nuis.setName("nuis")
     paired_globs.setName("globs")
     return convert_argsets(paired_pdfs, paired_nuis, paired_globs, fmt=fmt, to_str=to_str)
-        
+
 def pair_constraints_base_component(constraint_pdfs:ROOT.RooArgSet, nuisance_parameters:ROOT.RooArgSet,
                                     global_observables:ROOT.RooArgSet, fmt:str="list", to_str:bool=False,
                                     sort:bool=False):
@@ -96,14 +97,14 @@ def pair_constraints_base_component(constraint_pdfs:ROOT.RooArgSet, nuisance_par
                     target_component = nuis
                     break
         if not target_component:
-            self.stdout.warning(f'WARNING: Could not find base component for the constraint: {pdf_name}')
+            _PRINT_.warning(f'WARNING: Could not find base component for the constraint: {pdf_name}')
             continue
         for glob in global_observables:
             if pdf.dependsOn(glob):
                 target_glob = glob
                 break
         if not target_glob:
-            self.stdout.warning(f'WARNING: Could not find global observable for the constraint: {pdf_name}')
+            _PRINT_.warning(f'WARNING: Could not find global observable for the constraint: {pdf_name}')
             continue
         paired_pdfs.add(pdf)
         paired_component.add(target_component)
