@@ -6,7 +6,7 @@ import matplotlib
 from quickstats.plots.color_schemes import QUICKSTATS_PALETTES
 from quickstats.plots.template import (single_frame, parse_styles, format_axis_ticks,
                                        parse_analysis_label_options)
-from quickstats.utils.common_utils import combine_dict
+from quickstats.utils.common_utils import combine_dict, insert_periodic_substr
 
 class AbstractPlot:
     
@@ -17,7 +17,10 @@ class AbstractPlot:
     COLOR_PALLETE = {}
     COLOR_PALLETE_SEC = {}
     
-    CONFIG = {}
+    CONFIG = {
+        "xlabellinebreak": 50,
+        "ylabellinebreak": 50
+    }
     
     def __init__(self,
                  color_pallete:Optional[Dict]=None,
@@ -46,13 +49,17 @@ class AbstractPlot:
         
         self.figure_index = figure_index
         
-        self.config = combine_dict(self.CONFIG)
+        self.config = combine_dict(AbstractPlot.CONFIG, self.CONFIG)
         if config is not None:
             self.config = combine_dict(self.config, config)
 
         if color_cycle is None:
             self.prop_cycle = (cycler(color=self.COLOR_CYCLE))
         else:
+            if isinstance(color_cycle, str):
+                if color_cycle not in QUICKSTATS_PALETTES:
+                    raise RuntimeError(f"unknown color palette: {color_cycle}")
+                color_cycle = QUICKSTATS_PALETTES[color_cycle]
             self.prop_cycle = (cycler(color=color_cycle))
             
         self.annotation_list = []
@@ -117,16 +124,23 @@ class AbstractPlot:
         self.figure = matplotlib.pyplot.gcf()
         return ax
     
-    def draw_axis_labels(self, ax, xlabel:Optional[str]=None, ylabel:Optional[str]=None):
+    def draw_axis_labels(self, ax, xlabel:Optional[str]=None, ylabel:Optional[str]=None,
+                         xlabellinebreak:Optional[int]=None, ylabellinebreak:Optional[int]=None):
         if xlabel is not None:
+            if xlabellinebreak is not None:
+                xlabel = insert_periodic_substr(xlabel, xlabellinebreak)
             ax.set_xlabel(xlabel, **self.styles['xlabel'])
         if ylabel is not None:
+            if ylabellinebreak is not None:
+                ylabel = insert_periodic_substr(ylabel, ylabellinebreak)            
             ax.set_ylabel(ylabel, **self.styles['ylabel'])
             
     def draw_axis_components(self, ax, xlabel:Optional[str]=None, ylabel:Optional[str]=None,
                              ylim:Optional[Tuple[float]]=None, xlim:Optional[Tuple[float]]=None):
         
-        self.draw_axis_labels(ax, xlabel, ylabel)
+        self.draw_axis_labels(ax, xlabel, ylabel,
+                              xlabellinebreak=self.config["xlabellinebreak"],
+                              ylabellinebreak=self.config["ylabellinebreak"],)
         
         format_axis_ticks(ax, **self.styles['axis'],
                           xtick_styles=self.styles['xtick'],
@@ -138,16 +152,23 @@ class AbstractPlot:
             ax.set_xlim(*xlim)
     
     def set_axis_range(self, ax, xmin:Optional[float]=None, xmax:Optional[float]=None,
-                       ymin:Optional[float]=None, ymax:Optional[float]=None):
+                       ymin:Optional[float]=None, ymax:Optional[float]=None,
+                       ypad:Optional[float]=None):
         xlim = list(ax.get_xlim())
         ylim = list(ax.get_ylim())
         if xmin is not None:
             xlim[0] = xmin
         if xmax is not None:
             xlim[1] = xmax
+        if ypad is not None:
+            if (ymin is not None) or (ymax is not None):
+                raise ValueError('can not use both "ypad" and "ymin"/"ymax" when setting axis range')
+            if ypad < 0 or ypad > 1:
+                raise ValueError('"ypad" must be between 0 and 1')
+            ylim[1] = ylim[1] / (1 - ypad)
         if ymin is not None:
             ylim[0] = ymin
         if ymax is not None:
-            ylim[1] = ymax
+            ylim[1] = ymax                
         ax.set_xlim(*xlim)
         ax.set_ylim(*ylim)
\ No newline at end of file
