@@ -17,7 +17,7 @@ from quickstats.utils.common_utils import update_nested_dict
 class NumericFormatter(ScalarFormatter):
     def __call__(self, x, pos=None):
         tmp_format = self.format
-        if x.is_integer():
+        if (x.is_integer() and abs(x) < 1e3):
             self.format = re.sub(r"1\.\d+f", r"1.0f", self.format)
         result = super().__call__(x, pos)
         self.format = tmp_format
@@ -45,6 +45,7 @@ TEMPLATE_STYLES = {
             'minor_width': 1,
             'spine_width': 2,
             'labelsize': 20,
+            'offsetlabelsize': 20,
             'tick_bothsides': True
         },
         'xtick':{
@@ -77,6 +78,9 @@ TEMPLATE_STYLES = {
         'plot':{
             'linewidth': 2
         },
+        'hist': {
+            'linewidth': 2
+        },
         'errorbar': {
             "marker": 'x',
             "linewidth": 0,
@@ -217,6 +221,7 @@ def format_axis_ticks(ax, x_axis=True, y_axis=True, major_length:int=16, minor_l
                       spine_width:int=2, major_width:int=2, minor_width:int=1, 
                       label_bothsides:bool=False, tick_bothsides:bool=False,
                       labelsize:Optional[int]=None,
+                      offsetlabelsize:Optional[int]=None,
                       x_axis_styles:Optional[Dict]=None, 
                       y_axis_styles:Optional[Dict]=None,
                       xtick_styles:Optional[Dict]=None,
@@ -249,11 +254,25 @@ def format_axis_ticks(ax, x_axis=True, y_axis=True, major_length:int=16, minor_l
                        width=major_width, **styles)
         ax.tick_params(axis="y", which="minor", direction='in', length=minor_length,
                        width=minor_width, **styles)
+        
     for axis in ['top','bottom','left','right']:
         ax.spines[axis].set_linewidth(spine_width)
+        
     set_axis_tick_styles(ax.xaxis, xtick_styles)
     set_axis_tick_styles(ax.yaxis, ytick_styles)
 
+    # take care of offset labels
+    if offsetlabelsize is None:
+        offsetlabelsize = labelsize
+    # update the offset text
+    plt.tight_layout()
+    if ax.xaxis.get_offset_text().get_text():
+        ax.xaxis.get_offset_text().set_fontsize(offsetlabelsize)
+        ax.xaxis.labelpad = ax.xaxis.labelpad + ax.xaxis.get_offset_text().get_fontsize()
+    if ax.yaxis.get_offset_text().get_text():
+        ax.yaxis.get_offset_text().set_fontsize(offsetlabelsize)
+        ax.yaxis.labelpad = ax.yaxis.labelpad + ax.yaxis.get_offset_text().get_fontsize()
+
 def set_axis_tick_styles(ax, styles=None):   
     if styles is None:
         return None
